Exception: OData::NotSupportedError
- Inherits:
-
StandardError
- Object
- StandardError
- OData::NotSupportedError
- Defined in:
- lib/ruby_odata/exceptions.rb
Overview
Raised when a user attempts to do something that is not supported
Raised when a user attempts to do something that is not supported